from AnyQt.QtWidgets import QLabel
from Orange.widgets.widget import OWWidget
from orangewidget.widget import OWBaseWidget, Output, Input
from orangewidget.settings import Setting
from orangewidget import gui
from dynamikontrol import Module
import time


class Angle(OWWidget):
    name = 'Angle'
    icon = 'icons/angle.png'
    description = '''Control the motor by angle by degree. 모터를 각도로 제어합니다 (단위: 도).'''
    want_main_area = False

    module = None
    angle = Setting(0)
    period = Setting(0)

    def __init__(self):
        super().__init__()

        self.optionsBox = gui.widgetBox(self.controlArea, 'Controller')
        gui.spin(self.optionsBox, self, 'angle',
            minv=-80, maxv=80, step=1, label='Angle (-80 ~ 80 degrees)',
            callback=self.commit)
        gui.doubleSpin(self.optionsBox, self, 'period',
            minv=0, maxv=5, step=0.1, label='Period (0.0 ~ 5.0 seconds)')

        self.Outputs.module.send(self.module)

    class Inputs:
        module = Input('Module', object, auto_summary=False)
        angle = Input('Angle', int, auto_summary=False)

    class Outputs:
        module = Output('Module', object, auto_summary=False)

    def commit(self):
        if self.module is None:
            return

        period = self.period
        if period < 0.1:
            period = None

        self.module.motor.angle(int(self.angle), period=period)
        time.sleep(self.period)

        self.Outputs.module.send(self.module)

    @Inputs.module
    def set_module(self, module):
        if self.module is None:
            self.module = module

        self.commit()

    @Inputs.angle
    def set_angle(self, angle):
        self.angle = angle

        self.commit()

if __name__ == '__main__':
    from Orange.widgets.utils.widgetpreview import WidgetPreview  # since Orange 3.20.0
    WidgetPreview(Angle).run()



from Orange.widgets.widget import OWWidget, Output
from Orange.widgets.settings import Setting
from Orange.widgets import gui
from AnyQt.QtGui import QIntValidator

class Integer(OWWidget):
    # Widget's name as displayed in the canvas
    name = 'Integer'
    # Short widget description
    description = 'Lets the user input a number'

    # An icon resource file path for this widget
    # (a path relative to the module where this widget is defined)
    icon = 'icons/mywidget.svg'

    number = Setting(0)

    # Widget's outputs; here, a single output named 'Number', of type int
    class Outputs:
        number = Output('Number', int)

    def __init__(self):
        super().__init__()

        gui.lineEdit(self.controlArea, self, 'number', 'Enter a number',
                    box='Number',
                    callback=self.number_changed,
                    valueType=int, validator=QIntValidator())
        self.number_changed()

    def number_changed(self):
        # Send the entered number on 'Number' output
        self.Outputs.number.send(self.number)



from AnyQt.QtWidgets import QLabel
from Orange.widgets.widget import OWWidget
from orangewidget.widget import OWBaseWidget, Output
from orangewidget.settings import Setting
from orangewidget import gui
from dynamikontrol import Module


class Motor(OWWidget):
    name = 'Motor'
    icon = 'icons/motor.png'
    description = '''Initialize a motor module. 모터 모듈을 초기화합니다.'''
    want_main_area = False

    module = None

    def __init__(self):
        super().__init__()

        self.optionsBox = gui.widgetBox(self.controlArea, 'Controller')

        # label = QLabel('Hello, Motor!')
        # self.optionsBox.layout().addWidget(label)

        gui.button(self.optionsBox, self, 'Run', callback=self.run)
        gui.button(self.optionsBox, self, 'Reset', callback=self.reset)

        try:
            self.module = Module()
            self.Outputs.module.send(self.module)
        except:
            print('Module is not connected!')

    class Outputs:
        module = Output('Module', object, auto_summary=False)

    def run(self):
        if self.module is None:
            return

        self.Outputs.module.send(self.module)

    def reset(self):
        if self.module is None:
            return

        self.module.motor.angle(0)

    def onDeleteWidget(self):
        if self.module is None:
            return

        self.module.disconnect()
        self.module = None
        super().onDeleteWidget()



if __name__ == '__main__':
    from Orange.widgets.utils.widgetpreview import WidgetPreview  # since Orange 3.20.0
    WidgetPreview(Motor).run()
